==> vtigercrm-5.3.0p0.tgz: modules/Vendors/language/es_mx.lang.php <==
<?php
/*********************************************************************************
** The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ********************************************************************************
*  Module       : Vendors
*  Language     : Español
*  Version      : 504
*  Created Date : 2007-03-30
*  Author       : Rafael Soler
*  Last change  : 2008-09-20
*  Author       : Joe Bordes  JPL TSolucio, S.L.
*  Author       : Francisco Hernandez Odin Consultores www.odin.mx
 ********************************************************************************/

$mod_strings = array (

'LBL_VENDOR_INFORMATION'=>'Información sobre Proveedores:',
'LBL_CUSTOM_INFORMATION'=>'Información Personalizada',
'LBL_VENDOR_ADDRESS_INFORMATION'=>'Información sobre la Dirección:',
'LBL_DESCRIPTION_INFORMATION'=>'Descripción Adicional:',


'Vendor Name'=>'Proveedor',
'Name'=>'Nombre',
'Company Name'=>'Empresa',
'Phone'=>'Teléfono',
'Email'=>'Email',
'Website'=>'Página Web',
'GL Account'=>'Cuenta Contable',
'Category'=>'Categoría',
'Street'=>'Calle',
'City'=>'Deleg./Mpio.',
'State'=>'Estado',
'Postal Code'=>'Código Postal',
'Country'=>'País',
'Description'=>'Descripción',
'Po Box'=>'Colonia',
'Vendor'=>'Proveedor',

//Added for existing Picklist entries

'300-Sales-Software'=>'300-Ventas-Software',
'301-Sales-Hardware'=>'301-Ventas-Hardware',
'302-Rental-Income'=>'302-Ingreso-Alquiler',
'303-Interest-Income'=>'303-Ingreso-Intereses',
'304-Sales-Software-Support'=>'304-Ventas-Software-Soporte',
'305-Sales Other'=>'305-Ventas-Otros',
'306-Internet Sales'=>'306-Ventas-Internet',
'307-Service-Hardware Labor'=>'307-Instalación de Hardware-Ventas',
'308-Sales-Books'=>'308-Ventas-Libros',

// Added/Updated for vtiger CRM 5.0.4
'Created Time'=>'Creado',
'Modified Time'=>'Modificado Time',

// Added after 5.0.4 GA

//added for find duplicate
'LBL_DUPLICATE_DATA_IN'=>'Duplicar ',
'LBL_DELETE'=>'Eliminar',
'LBL_MERGE_SELECT'=>'Combinar Selección',
'LBL_MERGE_DATA_IN'=>'Combinar Registro',
'LBL_MERGE'=>'Combinar',
'LBL_ACTION'=>'Acción',
'LBL_FIELDLISTS'=> 'Lista de Campos',
'LBL_RECORD'=>'Registro #',

// Module Sequence Numbering
'Vendor No' => 'Núm. Proveedor',
// END

/*
 * 5.2.0 changes 
 */
'LBL_MODULE_NAME'=>'Proveedores',

);
?>

==> vtigercrm-5.4.0.tgz: modules/Vendors/language/es_mx.lang.php <==
<?php
/*********************************************************************************
** The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ********************************************************************************
*  Module       : Vendors
*  Language     : Español
*  Version      : 5.4.0
*  Created Date : 2007-03-30
*  Author       : Rafael Soler
*  Last change  : 2012-02-28
*  Author       : Joe Bordes  JPL TSolucio, S.L.
*  Author       : Francisco Hernandez Odin Consultores www.odin.mx
 ********************************************************************************/

$mod_strings = array (

'LBL_VENDOR_INFORMATION'=>'Información sobre Proveedores:',
'LBL_CUSTOM_INFORMATION'=>'Información Personalizada',
'LBL_VENDOR_ADDRESS_INFORMATION'=>'Información sobre la Dirección:',
'LBL_DESCRIPTION_INFORMATION'=>'Descripción Adicional:',


'Vendor Name'=>'Proveedor',
'Name'=>'Nombre',
'Company Name'=>'Empresa',
'Phone'=>'Teléfono',
'Email'=>'Email',
'Website'=>'Página Web',
'GL Account'=>'Cuenta Contable',
'Category'=>'Categoría',
'Street'=>'Calle',
'City'=>'Deleg./Mpio.',
'State'=>'Estado',
'Postal Code'=>'Código Postal',
'Country'=>'País',
'Description'=>'Descripción',
'Po Box'=>'Colonia',
'Vendor'=>'Proveedor',

//Added for existing Picklist entries

'300-Sales-Software'=>'300-Ventas-Software',
'301-Sales-Hardware'=>'301-Ventas-Hardware',
'302-Rental-Income'=>'302-Ingreso-Alquiler',
'303-Interest-Income'=>'303-Ingreso-Intereses',
'304-Sales-Software-Support'=>'304-Ventas-Software-Soporte',
'305-Sales Other'=>'305-Ventas-Otros',
'306-Internet Sales'=>'306-Ventas-Internet',
'307-Service-Hardware Labor'=>'307-Instalación de Hardware-Ventas',
'308-Sales-Books'=>'308-Ventas-Libros',

// Added/Updated for vtiger CRM 5.0.4
'Created Time'=>'Creado',
'Modified Time'=>'Modificado Time',

// Added after 5.0.4 GA

//added for find duplicate
'LBL_DUPLICATE_DATA_IN'=>'Duplicar ',
'LBL_DELETE'=>'Eliminar',
'LBL_MERGE_SELECT'=>'Combinar Selección',
'LBL_MERGE_DATA_IN'=>'Combinar Registro',
'LBL_MERGE'=>'Combinar',
'LBL_ACTION'=>'Acción',
'LBL_FIELDLISTS'=> 'Lista de Campos',
'LBL_RECORD'=>'Registro #',

// Module Sequence Numbering
'Vendor No' => 'Núm. Proveedor',
'Vendors ID'=>'Id Proveedor',
// END

/*
 * 5.2.0 changes 
 */
'LBL_MODULE_NAME'=>'Proveedores',

);
?>
